==> phoenix-starter-scheduling-0.1.2-20230913.084631-1-sources.jar: com/elitesland/cbpl/scheduling/vo/param/ScheduleConfigPagingParamVO.java <==
package com.elitesland.cbpl.scheduling.vo.param;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.elitescloud.boot.common.param.AbstractOrderQueryParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.time.LocalDateTime;

/**
 * 定时任务配置表
 *
 * @author eric.hao
 * @since 2023/09/06
 */
@Data
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
@ApiModel("定时任务配置表")
public class ScheduleConfigPagingParamVO extends AbstractOrderQueryParam {

	@ApiModelProperty(value = "主键")
	private Long id;

	@ApiModelProperty(value = "定时任务名称")
	private String taskName;

	@ApiModelProperty(value = "定时任务编码")
	private String taskCode;

	@ApiModelProperty(value = "类名")
	private String className;

	@ApiModelProperty(value = "方法名")
	private String method;

	@ApiModelProperty(value = "定时任务表达式")
	private String cron;

	@ApiModelProperty(value = "启用标记")
	private String activeFlag;

	@ApiModelProperty(value = "所属租户ID")
	private Long tenantId;

	@ApiModelProperty(value = "所属组织ID")
	private Long belongOrgId;

	@ApiModelProperty(value = "租户组织ID")
	private Long tenantOrgId;

	@ApiModelProperty(value = "备注")
	private String remark;

	@ApiModelProperty(value = "记录创建者ID")
	private Long createUserId;

	@ApiModelProperty(value = "记录创建者")
	private String creator;

	@ApiModelProperty(value = "记录创建时间")
	private LocalDateTime createTime;

	@ApiModelProperty(value = "记录最后更新者ID")
	private Long modifyUserId;

	@ApiModelProperty(value = "记录最后更新者")
	private String updater;

	@ApiModelProperty(value = "记录最后更新时间")
	private LocalDateTime modifyTime;

	@ApiModelProperty(value = "删除标记")
	private Integer deleteFlag;

	@ApiModelProperty(value = "锁版本")
	private Integer auditDataVersion;

	@ApiModelProperty(value = "数据归属组织id")
	private Long secBuId;

	@ApiModelProperty(value = "数据归属雇员id")
	private Long secUserId;

	@ApiModelProperty(value = "数据归属公司id")
	private Long secOuId;
}

==> phoenix-starter-scheduling-0.1.4.6-20240117.074246-1-sources.jar: com/elitesland/cbpl/scheduling/vo/param/ScheduleConfigPagingParamVO.java <==
package com.elitesland.cbpl.scheduling.vo.param;

import com.elitesland.cbpl.tool.db.PageQueryParam;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.time.LocalDateTime;

/**
 * 定时任务配置表
 *
 * @author eric.hao
 * @since 2023/09/06
 */
@Data
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
@ApiModel("定时任务配置表")
public class ScheduleConfigPagingParamVO extends PageQueryParam {

	@ApiModelProperty(value = "主键")
	private Long id;

	@ApiModelProperty(value = "任务编码/名称")
	private String taskCodeName;

	@ApiModelProperty(value = "定时任务名称")
	private String taskName;

	@ApiModelProperty(value = "定时任务编码")
	private String taskCode;

	@ApiModelProperty(value = "类名")
	private String className;

	@ApiModelProperty(value = "方法名")
	private String method;

	@ApiModelProperty(value = "定时任务表达式")
	private String cron;

	@ApiModelProperty(value = "启用标记")
	private String activeFlag;

	@ApiModelProperty(value = "所属租户ID")
	private Long tenantId;

	@ApiModelProperty(value = "所属组织ID")
	private Long belongOrgId;

	@ApiModelProperty(value = "租户组织ID")
	private Long tenantOrgId;

	@ApiModelProperty(value = "备注")
	private String remark;

	@ApiModelProperty(value = "记录创建者ID")
	private Long createUserId;

	@ApiModelProperty(value = "记录创建者")
	private String creator;

	@ApiModelProperty(value = "记录创建时间")
	private LocalDateTime createTime;

	@ApiModelProperty(value = "记录最后更新者ID")
	private Long modifyUserId;

	@ApiModelProperty(value = "记录最后更新者")
	private String updater;

	@ApiModelProperty(value = "记录最后更新时间")
	private LocalDateTime modifyTime;

	@ApiModelProperty(value = "删除标记")
	private Integer deleteFlag;

	@ApiModelProperty(value = "锁版本")
	private Integer auditDataVersion;

	@ApiModelProperty(value = "数据归属组织id")
	private Long secBuId;

	@ApiModelProperty(value = "数据归属雇员id")
	private Long secUserId;

	@ApiModelProperty(value = "数据归属公司id")
	private Long secOuId;
}
